import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListManagedNotificationConfigurationsRequest, ListManagedNotificationConfigurationsResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListManagedNotificationConfigurationsCommand}.
 */
export interface ListManagedNotificationConfigurationsCommandInput extends ListManagedNotificationConfigurationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListManagedNotificationConfigurationsCommand}.
 */
export interface ListManagedNotificationConfigurationsCommandOutput extends ListManagedNotificationConfigurationsResponse, __MetadataBearer {
}
declare const ListManagedNotificationConfigurationsCommand_base: {
    new (input: ListManagedNotificationConfigurationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListManagedNotificationConfigurationsCommandInput, ListManagedNotificationConfigurationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListManagedNotificationConfigurationsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListManagedNotificationConfigurationsCommandInput, ListManagedNotificationConfigurationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of Managed Notification Configurations according to specified filters, ordered by creation time in reverse chronological order (newest first).</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, ListManagedNotificationConfigurationsCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, ListManagedNotificationConfigurationsCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // ListManagedNotificationConfigurationsRequest
 *   channelIdentifier: "STRING_VALUE",
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListManagedNotificationConfigurationsCommand(input);
 * const response = await client.send(command);
 * // { // ListManagedNotificationConfigurationsResponse
 * //   nextToken: "STRING_VALUE",
 * //   managedNotificationConfigurations: [ // ManagedNotificationConfigurations // required
 * //     { // ManagedNotificationConfigurationStructure
 * //       arn: "STRING_VALUE", // required
 * //       name: "STRING_VALUE", // required
 * //       description: "STRING_VALUE", // required
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListManagedNotificationConfigurationsCommandInput - {@link ListManagedNotificationConfigurationsCommandInput}
 * @returns {@link ListManagedNotificationConfigurationsCommandOutput}
 * @see {@link ListManagedNotificationConfigurationsCommandInput} for command's `input` shape.
 * @see {@link ListManagedNotificationConfigurationsCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class ListManagedNotificationConfigurationsCommand extends ListManagedNotificationConfigurationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListManagedNotificationConfigurationsRequest;
            output: ListManagedNotificationConfigurationsResponse;
        };
        sdk: {
            input: ListManagedNotificationConfigurationsCommandInput;
            output: ListManagedNotificationConfigurationsCommandOutput;
        };
    };
}
